@@ -65,7 +65,6 @@ extern char ** environ;
 #define fgetc win32_fgetc
 #define random rand
 #define srandom srand
-#include <process.h>
 #include <conio.h>  
 #include <dir.h>
 #define popen  _popen
@@ -78,6 +77,7 @@ See also http://www.mingw.org/MinGWiki/index.php/binary
 */
 unsigned int _CRT_fmode = _O_BINARY;
 
+
 int setenv (const char *name, const char *value, int replace);
 #ifdef USE_WIN_UTF16PATH
 INT64 fileSizeW(WCHAR * pathName);
@@ -102,6 +102,7 @@ extern int pagesize;
 
 extern char * errorMessage[];
 extern STREAM errorStream;
+extern UINT netErrorIdx;
 
 /* semaphore() function type */
 #define SEM_CREATE 0
@@ -236,9 +237,8 @@ UINT handle;
 getInteger(params, &handle);
 if(handle == 0) return(nilCell);
 if(handle == printDevice) printDevice = 0;
-deleteIOsession(handle);
-if(close((int)handle) == -1) return(nilCell);
-return(trueCell);
+if(deleteIOsession(handle)) return(trueCell);
+return(nilCell);
 }
 
 
@@ -340,9 +340,7 @@ params = getString(params, &fileName);
 if(my_strnicmp(fileName, "http://", 7) == 0)
     {
     result = getPutPostDeleteUrl(fileName, params, HTTP_GET, CONNECT_TIMEOUT);
-    if(memcmp((char *)result->contents, "ERR:", 4) == 0)
-        return(errorProcExt2(ERR_ACCESSING_FILE, stuffString((char *)result->contents)));
-    return(result);
+    return((my_strnicmp((char *)result->contents, (char *)"ERR:", 4) == 0) && netErrorIdx ? nilCell : result);
     }
 
 if((size = readFile(fileName, &buffer)) == -1)
@@ -461,9 +459,7 @@ if(my_strnicmp(fileName, "http://", 7) == 0)
     {
     result = getPutPostDeleteUrl(fileName, params, 
                 (*type == 'w') ? HTTP_PUT : HTTP_PUT_APPEND, CONNECT_TIMEOUT);
-    if(memcmp((char *)result->contents, "ERR:", 4) == 0)
-        return(errorProcExt2(ERR_ACCESSING_FILE, stuffString((char *)result->contents)));
-    return(result);
+    return((my_strnicmp((char *)result->contents, (char *)"ERR:", 4) == 0) && netErrorIdx ? nilCell : result);
     }
 
 getStringSize(params, &buffer, &size, TRUE);
@@ -789,7 +785,7 @@ params = getString(params, &fileName);
 if(my_strnicmp(fileName, "http://", 7) == 0)
     {
     result = getPutPostDeleteUrl(fileName, params, HTTP_DELETE, CONNECT_TIMEOUT);
-    return(my_strnicmp((char *)result->contents, (char *)"ERR:", 4) == 0 ? nilCell : trueCell);
+    return((my_strnicmp((char *)result->contents, (char *)"ERR:", 4) == 0) && netErrorIdx ? nilCell : result);
     }
 
 fileName = getLocalPath(fileName);
@@ -1096,9 +1092,10 @@ return(argc);
 
 
 #ifdef WIN_32
+int kill(pid_t pid, int sig);
 int winPipe(UINT * inpipe, UINT * outpipe);
 UINT winPipedProcess(char * command, int inpipe, int outpipe, int option);
-CELL * plainProcess(char * command, size_t size);
+UINT plainProcess(char * command, size_t size);
 
 CELL * p_pipe(CELL * params)
 {
@@ -1132,50 +1129,15 @@ if(params != nilCell)
     params = getInteger(params, (UINT *)&outpipe);
     if(params != nilCell)
         getInteger(params, (UINT *)&option);
+	result = winPipedProcess(command, (int)inpipe, (int)outpipe, (int)option);
     }
-else return(plainProcess(command, size));
-
-result = winPipedProcess(command, (int)inpipe, (int)outpipe, (int)option);
+else result = plainProcess(command, size);
 
 if(!result) return(nilCell);
 
 return(stuffInteger(result));
 }
 
-CELL * plainProcess(char * command, size_t len)
-{
-char * cPtr;
-char * argv[16];
-int idx;
-
-cPtr = callocMemory(len + 1);
-memcpy(cPtr, command, len + 1);
-
-init_argv(cPtr, argv);
-
-idx = spawnvp(P_NOWAIT, argv[0], (const char * const *)argv); 
-
-free(cPtr);
-if(idx == -1) return(nilCell);
-
-return(stuffInteger(idx));
-}
-
-
-CELL * p_destroyProcess(CELL * params)
-{
-UINT pid;
-
-getInteger(params, &pid);
-
-/* GetProcessId(handle) */
-
-if(TerminateProcess((HANDLE)pid, 0) == 0)
-    return(nilCell);
-
-return(trueCell);
-}
-
 
 #else /* not WIN_32 */
 
@@ -1847,23 +1809,6 @@ return(nilCell);
 /* --------------------------- end Cilk ------------------------------------- */
 
 
-CELL * p_destroyProcess(CELL * params)
-{
-UINT pid;
-UINT sig;
-
-params = getInteger(params, &pid);
-if(params != nilCell)   
-    getInteger(params, &sig);
-else
-    sig = 9;
-
-if(kill(pid, sig) != 0)
-    return(nilCell);
-
-return(trueCell);
-}
-
 extern SYMBOL * symHandler[];
 
 CELL * p_waitpid(CELL * params)
@@ -1893,6 +1838,23 @@ return(stuffIntegerList(2, (UINT)retval, (UINT)result));
 
 #endif
 
+CELL * p_destroyProcess(CELL * params)
+{
+UINT pid;
+UINT sig;
+
+params = getInteger(params, &pid);
+if(params != nilCell)   
+    getInteger(params, &sig);
+else
+    sig = 9;
+
+if(kill(pid, sig) != 0)
+    return(nilCell);
+
+return(trueCell);
+}
+
 /* ------------------------------ semaphores --------------------------------- */
 
 #ifdef WIN_32
@@ -2406,12 +2368,12 @@ char * ct;
 char * fmt;
 ssize_t offset;
 time_t tme;
+size_t size;
 
 #ifdef SUPPORT_UTF8
 #ifdef WCSFTIME
 int * ufmt;
 int * timeString;
-int size;
 #endif
 char * utf8str;
 #else
@@ -2436,12 +2398,12 @@ else
         
     if(params != nilCell)
         {
-        params = getString(params, &fmt);
+        params = getStringSize(params, &fmt, &size, TRUE);
         ltm = localtime(&t);
 #ifdef SUPPORT_UTF8
     /* some Linux do UTF-8 but don't have wcsftime() or it is buggy */
 #ifdef WCSFTIME
-        size = utf8_wlen(fmt);
+        size = utf8_wlen(fmt, fmt + size + 1);
         ufmt = alloca(UTF8_MAX_BYTES * (size + 1));
         utf8_wstr(ufmt, fmt, size);
 
